@@ -13,7 +13,7 @@ class SuggestionGenerator:
     ):
         self.forms_lookup = forms_lookup
         self.inflector = Inflector(nlp=nlp, forms_lookup=self.forms_lookup)
-        self.ref_matcher = RefMatcher(nlp)
+        self.ref_matcher = RefMatcher()
         self.filter_suggestions = filter_suggestions
         self.default_max_count = default_max_count
 
@@ -31,13 +31,13 @@ class SuggestionGenerator:
             ref = int(item["PATTERN_REF"])
             if ref >= 0:
                 try:
-                    refd_tokens = pattern_ref[ref]
-                    if len(refd_tokens):
-                        min_i = start + min(refd_tokens)
-                        max_i = start + max(refd_tokens)
-                        refd_text = doc[min_i : max_i + 1].text
-                    else:
-                        refd_text = None
+                    refd_text = None
+                    if ref in pattern_ref:
+                        refd_tokens = pattern_ref[ref]
+                        if len(refd_tokens):
+                            min_i = start + min(refd_tokens)
+                            max_i = start + max(refd_tokens)
+                            refd_text = doc[min_i : max_i + 1].text
                 except:
                     warnings.warn(
                         f"Ref matcher failed for span {doc[start:end]} and {pattern_ref}."
@@ -267,7 +267,9 @@ class SuggestionGenerator:
                 item_options = [t.upper() for t in item_options]
         return item_options
 
-    def __call__(self, pre_suggestion, doc, start, end, pattern, pre_suggestion_id):
+    def __call__(
+        self, pre_suggestion, doc, start, end, pattern, pre_suggestion_id, alignments
+    ):
         """
         Suggestion text:
             - set: "TEXT": "cat"
@@ -287,13 +289,14 @@ class SuggestionGenerator:
             - implied MAX_COUNT = 1 if words share the same lemma or are mutually exclusive, ex. a/an
         """
         # get token <-> pattern correspondence
-        pattern_ref = self.ref_matcher(doc[start:end], pattern)
+        pattern_obj = pattern[0]
+        pattern_ref = self.ref_matcher(doc[start:end], pattern_obj, alignments)
 
         generated_suggestions_obj = []
         for item in pre_suggestion:
             # get text
             item_options = SuggestionGenerator.get_options(
-                item, doc, start, end, pattern, pattern_ref
+                item, doc, start, end, pattern_obj, pattern_ref
             )
             item["generated"] = item_options
             generated_suggestions_obj.append(item)
@@ -304,7 +307,7 @@ class SuggestionGenerator:
             inflected_options = self.inflect(
                 item_idx,
                 generated_suggestions_obj,
-                pattern,
+                pattern_obj,
                 pattern_ref,
                 doc,
                 start,
